<?php

namespace EventPortal\Domain\Venue\Models;

use EventPortal\Concerns\AddToCasts;
use EventPortal\Concerns\AddToFillable;
use EventPortal\Domain\Address\Models\Address;
use EventPortal\Domain\Event\Models\Event;
use EventPortal\Domain\Model;
use EventPortal\Domain\Table\Concerns\HasTable;
use Illuminate\Database\Eloquent\Relations\MorphOne;
use Illuminate\Database\Eloquent\Relations\MorphTo;
use Illuminate\Database\Eloquent\Relations\MorphToMany;
use OwenIt\Auditing\Auditable;
use OwenIt\Auditing\Contracts\Auditable as AuditableInterface;

class Venue extends Model implements AuditableInterface
{
    use HasTable,
        AddToFillable,
        AddToCasts,
        Auditable;

    public const KEY = 'venue';

    /** @var array<string> */
    protected $fillable = [
        'name',
        'website',
        'star_rating',
        'has_green_tourism_accreditation',
    ];

    /** @var array<string> */
    protected $casts = [
        'star_rating' => 'array',
        'has_green_tourism_accreditation' => 'boolean',
    ];

    /** @var array<string> */
    protected $with = [
        'address',
    ];

    public function venueable(): MorphTo
    {
        return $this->morphTo();
    }

    public function events(): MorphToMany
    {
        return $this->morphedByMany(Event::class, 'venueable');
    }

    public function address(): MorphOne
    {
        return $this->morphOne(Address::class, 'addressable');
    }

    public function getIsVenuepotAttribute(): bool
    {
        return $this->source !== null;
    }
}
