<?php

use EventPortal\Domain\Component\Button;
use EventPortal\Domain\Component\ButtonDropdown;
use EventPortal\Domain\Component\Column\TextColumn;
use EventPortal\Domain\Event\Models\Event;
use EventPortal\Domain\Table\Facades\Table;
use EventPortal\Domain\Venue\Models\Venue;
use EventPortal\Enums\InertiaMethod;

Table::make('event-venue.index')
    ->setColumns(function () {
        return [
            TextColumn::make('Name')->default()->searchable(),
            TextColumn::make('Website')->default(),
        ];
    })
    ->setRowAction(function (Event $event, Venue $venue) {
        return ButtonDropdown::make('Manage venues')
            ->actions([
                Button::make('View')
                    ->method(InertiaMethod::VISIT())
                    ->route('admin.event.venue.show', [
                        'event' => $event->id,
                        'venue' => $venue->id,
                    ]),
            ]);
    });

Table::make('event-venue.add')
    ->setColumns(function () {
        return [
            TextColumn::make('Name')->default()->searchable(),
            TextColumn::make('Website')->default(),
        ];
    })
    ->addGlobalAction(function (Event $event) {
        return Button::make('Add venue to event')
            ->method(InertiaMethod::POST())
            ->route('admin.event.venue.store', [
                'event' => $event->id,
            ]);
    });
